%if %{defined fedora}
%define _TOMCAT "/usr/share/tomcat6"
%endif
%if %{defined suse_version}
%define _TOMCAT "/srv/tomcat"
%endif

Name: oat
Summary: Attestation Service & Host Agent based on OpenAttestation SDK
Version: 1.6.0 
Release: 1%{?dist}
License: BSD
Group: Cloud Infrastructure
Source0: %{name}-%{version}.tar.gz
Source1: %{name}-%{version}-jars.tar.gz
Patch0: oat-1.6.0-fedora-build.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: ant, trousers-devel
%if %{defined suse_version}
BuildRequires: java-1_7_0-openjdk-devel
%endif

%description
OpenAttestation (OAT) is a Intel initiated open source project providing a
SDK for managing host integraty verification using TCG-defined remote
attestation protocol, targeting to be integrated into cloud and enterprise
management tools.

%package appraiser
Summary: Appraisal Server for OpenAttestation
Version: 1.6.0
Release: 1%{?dist}
%if %{defined fedora}
Requires: httpd, tomcat6, mysql, mysql-server, php, php-mysql
%endif
%if %{defined suse_version}
Requires: apache2, tomcat, mysql, php5, php5-mysql, apache2-mod_php5, openssl
%endif

%description appraiser
OpenAttestation (OAT) is a Intel initiated open source project providing a
SDK for managing host integraty verification using TCG-defined remote
attestation protocol, targeting to be integrated into cloud and enterprise
management tools.

This package provides the OAT appraisal server.

%package client
Summary: Host Agent for OpenAttestation
Version: 1.6.0
Release: 1%{?dist}

%description client
OpenAttestation (OAT) is a Intel initiated open source project providing a
SDK for managing host integraty verification using TCG-defined remote
attestation protocol, targeting to be integrated into cloud and enterprise
management tools.

This package provides the host agent which uses Java and the NIARL TPM
Module to acquire integrity measurement data from the host's Trusted
Platform Module (TPM).

The data is compiled into an integrity report and sent to the OAT appraisal
server.

%package commandtool
Summary: Command line tools for OpenAttestation 
Version: 1.6.0
Release: 1%{?dist}
Requires: curl, openssl

%description commandtool
OpenAttestation (OAT) is a Intel initiated open source project providing a
SDK for managing host integraty verification using TCG-defined remote
attestation protocol, targeting to be integrated into cloud and enterprise
management tools.

This package provides a number of command line tools which are useful for
interacting with a OAT appraisal server.

%package docs
Summary: Documentation for OpenAttestation
Version: 1.6.0
Release: 1%{?dist}

%description docs
OpenAttestation (OAT) is a Intel initiated open source project providing a
SDK for managing host integraty verification using TCG-defined remote
attestation protocol, targeting to be integrated into cloud and enterprise
management tools.

This package provides the documentation for OpenAttestation.

%clean
rm -rf $RPM_BUILD_ROOT

%prep
%setup -T -b 0
%setup -a 1 -D
%patch0 -p1

%build
# distribute the JAR_SOURCE to the source tree
pushd Source
sh distribute_jar_packages.sh
sh build.sh
popd

%install
###################
#### appraiser ####
###################

# oat-appraiser dirs
mkdir -p $RPM_BUILD_ROOT/usr/share/oat-appraiser/
mkdir -p $RPM_BUILD_ROOT/var/lib/oat-appraiser/CaCerts
mkdir $RPM_BUILD_ROOT/var/lib/oat-appraiser/ClientFiles
mkdir $RPM_BUILD_ROOT/var/lib/oat-appraiser/Certificate
mkdir -p $RPM_BUILD_ROOT%_sysconfdir/oat-appraiser/

# copy post install setup files
cp Installer/OAT-Appraiser-Configure/linuxClientInstallRefresh.sh $RPM_BUILD_ROOT/usr/share/oat-appraiser
cp Installer/OAT-Appraiser-Configure/OAT_Server_Install/oat_db.MySQL $RPM_BUILD_ROOT/usr/share/oat-appraiser/
cp Installer/FilesForLinux/init.sql $RPM_BUILD_ROOT/usr/share/oat-appraiser/

# install configs
cp Installer/OAT-Appraiser-Configure/OAT_Server_Install/OAT.properties $RPM_BUILD_ROOT%_sysconfdir/oat-appraiser/ 

# tomcat install dir
mkdir -p $RPM_BUILD_ROOT/%_TOMCAT/webapps/

# install AttestationService
unzip Source/AttestationService/AttestationService.war -d $RPM_BUILD_ROOT/%_TOMCAT/webapps/AttestationService

# install WLMService
unzip Source/WLMService/WLMService.war -d $RPM_BUILD_ROOT/%_TOMCAT/webapps/WLMService

# install HisWebServices
mkdir -p $RPM_BUILD_ROOT/%_TOMCAT/webapps/HisWebServices
cp -R Source/HisWebServices/WEB-INF $RPM_BUILD_ROOT/%_TOMCAT/webapps/HisWebServices
cp Installer/OAT-Appraiser-Configure/OAT_Server_Install/hibernateOat.cfg.xml $RPM_BUILD_ROOT/%_TOMCAT/webapps/HisWebServices/WEB-INF/classes/
mv $RPM_BUILD_ROOT/%_TOMCAT/webapps/HisWebServices/WEB-INF/classes/OpenAttestation.properties $RPM_BUILD_ROOT%_sysconfdir/oat-appraiser/

# install HisPrivacyCAWebServices2
cp Source/HisPrivacyCAWebServices2/HisPrivacyCAWebServices2.war $RPM_BUILD_ROOT/%_TOMCAT/webapps/
echo  "\n\r" >> Source/HisPrivacyCAWebServices2/setup.properties
echo "ecSigningKeySize=2048" >> Source/HisPrivacyCAWebServices2/setup.properties
echo "ecStorage=NVRAM" >> Source/HisPrivacyCAWebServices2/setup.properties
cp Source/HisPrivacyCAWebServices2/setup.properties $RPM_BUILD_ROOT%_sysconfdir/oat-appraiser/

#placing OAT web portal in correct folder to be seen by tomcat6
%if %{defined fedora}
mkdir -p $RPM_BUILD_ROOT/var/www/html/
cp -R Source/Portal $RPM_BUILD_ROOT/var/www/html/OAT
%endif
%if %{defined suse_version}
mkdir -p $RPM_BUILD_ROOT/srv/www/htdocs
cp -R Source/Portal $RPM_BUILD_ROOT/srv/www/htdocs/OAT
%endif

################
#### client ####
################
mkdir -p $RPM_BUILD_ROOT/usr/share/oat-client/lib
mkdir -p $RPM_BUILD_ROOT%_sysconfdir/init.d
mkdir $RPM_BUILD_ROOT/usr/share/oat-client/script
mkdir $RPM_BUILD_ROOT/usr/share/oat-client/exe
mkdir -p $RPM_BUILD_ROOT/usr/share/oat-client/shells
cp -f Installer/FilesForLinux/shells/redhat-partner.sh $RPM_BUILD_ROOT%_sysconfdir/init.d/OATClient
cp Source/HisClient/OAT07.jpg Source/HisClient/log4j.properties $RPM_BUILD_ROOT/usr/share/oat-client/
cp Source/HisClient/jar/OAT_Standalone.jar $RPM_BUILD_ROOT/usr/share/oat-client/
cp -r Source/HisClient/lib $RPM_BUILD_ROOT/usr/share/oat-client/

cp -r Installer/FilesForLinux/shells/redhat-partner.sh $RPM_BUILD_ROOT/usr/share/oat-client/shells
cp Installer/FilesForLinux/provisioner-redhat-partner.sh $RPM_BUILD_ROOT/usr/share/oat-client/script/provisioner.sh
cp Source/PrivacyCA/TPMModule.properties $RPM_BUILD_ROOT/usr/share/oat-client/
cp Source/HisPrivacyCAWebServices2/ClientFiles/lib/* $RPM_BUILD_ROOT/usr/share/oat-client/lib/
cp Source/PrivacyCA/PrivacyCA.jar $RPM_BUILD_ROOT/usr/share/oat-client/lib/
cp Source/TPMModule/plain/linux/NIARL_TPM_Module $RPM_BUILD_ROOT/usr/share/oat-client/exe

cp Installer/OAT_configure.sh $RPM_BUILD_ROOT/usr/share/oat-appraiser/OAT_configure.sh

#####################
#### commandtool ####
#####################
mkdir -p $RPM_BUILD_ROOT/usr/bin
cp CommandTool/oat_* $RPM_BUILD_ROOT/usr/bin

##############
#### docs ####
##############

%post appraiser

%preun appraiser
echo "remove oat-appraiser data file: /var/lib/oat-appraiser  ...ok"
[[ -d /var/lib/oat-appraiser/ ]] && rm -rf /var/lib/oat-appraiser/
echo "remove oat-appraiser conf file: /etc/oat-appraiser  ...ok"
[[ -d /etc/oat-appraiser/ ]] && rm -rf /etc/oat-appraiser/
echo "remove oat-appraiser file: /usr/share/oat-appraiser  ...ok"
[[ -d /usr/share/oat-appraiser/ ]] && rm -rf /usr/share/oat-appraiser/

echo "drop database oat_db  ...ok"
mysql -u root --execute="FLUSH PRIVILEGES; DROP DATABASE IF EXISTS oat_db; DELETE FROM mysql.user WHERE User='oatAppraiser' and Host='localhost';"

echo "remove oat_appraiser tomcat6 conf   ...ok"
sed -i "/<\/Service>/d" %{_TOMCAT}/conf/server.xml
sed -i "/<\/Server>/i\\  <\/Service>"  %{_TOMCAT}/conf/server.xml
#... modify?
sed -i '/oat/d' %{_TOMCAT}/conf/context.xml 

%files appraiser
%config /etc/oat-appraiser/
%dir /var/lib/oat-appraiser/CaCerts
%dir /var/lib/oat-appraiser/Certificate
/var/lib/oat-appraiser/ClientFiles
/usr/share/oat-appraiser

%if %{defined fedora}
/var/www/html/OAT
%endif
%if %{defined suse_version}
/srv/www/htdocs/OAT
%endif

%if %{defined fedora}
/usr/share/tomcat6/webapps/AttestationService
/usr/share/tomcat6/webapps/WLMService
/usr/share/tomcat6/webapps/HisWebServices
/usr/share/tomcat6/webapps/HisPrivacyCAWebServices2.war
%endif
%if %{defined suse_version}
/srv/tomcat/webapps/AttestationService
/srv/tomcat/webapps/HisWebServices
/srv/tomcat/webapps/HisPrivacyCAWebServices2.war
%endif


%post client
#TODO: chkconfig on the system script
#get hostname of appraiser
mkdir -p /etc/oat-client/
mkdir -p /usr/share/oat-client/
mkdir -p /usr/share/oat-client/
mkdir -p /OAT/

TMP="./appraiser.hostnameOoooooOOO"
cat /dev/null > $TMP
appraiser_hostname()
{
   dialog  --no-cancel --no-ok --title "OpenAttestation" \
        --backtitle "OpenAttestation client installation" \
        --inputbox "Input OAT appraiser hostname:" 16 51 "" 2>$TMP
   clear
}

appraiser_hostname
if [ ! -s $TMP ];then
  appraiser_hostname_str="APPRAISER_HOSTNAME"
else
  appraiser_hostname_str="`cat $TMP`"
fi

#OAT.properties
OATProperties()
{
   echo "WebServiceUrl=https://$appraiser_hostname_str:8443/HisWebServices"
   echo "KeyAuth=1111111111111111111111111111111111111111"
   echo "KeyIndex=1"
   echo "TpmQuoteExecutableName=NIARL_TPM_Module"
   echo "SplashImage=OAT07.jpg"
   echo "TrustStore=TrustStore.jks"
}

OATProperties > /usr/share/oat-client/OAT.properties
if [ ! -s $TMP ];then
  echo "oat client attestation config   ...FAILD"
else
  echo "oat client attestation config   ...ok"
fi
#OATprovisioner.properties
OATprovisionerProperties()
{
   echo "EcValidityDays = 3652"
   echo "TpmOwnerAuth = 1111111111111111111111111111111111111111"
   echo "HisIdentityLabel = HIS Identity Key"
   echo "HisIdentityIndex = 1"
   echo "HisIdentityAuth = 1111111111111111111111111111111111111111"
   echo "PrivacyCaCertFile = PrivacyCA.cer"
   echo "PrivacyCaUrl = https://$appraiser_hostname_str:8443/HisPrivacyCAWebServices2"
   echo "HisRegistrationUrl = https://$appraiser_hostname_str:8443/HisWebServices"
   echo "TrustStore = TrustStore.jks"
   echo "NtruBypass = true"
   echo "ClientPath = /usr/share/oat-client"
   echo "ecStorage = NVRAM"
   echo "ecSigningKeySize = 2048"
}

OATprovisionerProperties  > /usr/share/oat-client/OATprovisioner.properties
if [ ! -s $TMP ];then
   echo "oat client provisioner config   ...FAILD"
   echo "oat client installation  ...FAILD"
    echo "oat appraiser hostname is NULL"
else
   echo "oat client provisioner config   ...ok"
   echo "oat client installation  ...ok"
   echo "oat appraiser hostname: $appraiser_hostname_str"
fi

%preun client
#TODO: stop the service before removing

echo "stop oat-client daemon              ...ok"
[[ -e /etc/init.d/OATClient ]] && /etc/init.d/OATClient stop
echo "delete oat-client conf files            ...ok"
[[ -d /etc/oat-client/ ]] && rm -rf /etc/oat-client/
echo "delete oat-client files                 ...ok"
[[ -d /usr/share/oat-client ]] && rm -rf /usr/share/oat-client
echo "delete oat-client data                  ...ok"
[[ -d /var/lib/oat-client ]] && rm -rf /var/lib/oat-client
[[ -d /OAT/ ]] && rm -rf /OAT/

%files client
%attr(755,-,-) /etc/init.d/OATClient
/usr/share/oat-client/OAT07.jpg
/usr/share/oat-client/OAT_Standalone.jar
/usr/share/oat-client/log4j.properties
/usr/share/oat-client/lib
/usr/share/oat-client/script/provisioner.sh
/usr/share/oat-client/exe/NIARL_TPM_Module
/usr/share/oat-client/TPMModule.properties
/usr/share/oat-client/shells/redhat-partner.sh

%files commandtool
/usr/bin/oat_*

%files docs
%doc README docs/*

%changelog
* Tue Feb 26 2013 Gang Wei <gang.wei@intel.com> - 0:1.6.0-1
- Initial import
